set_exported_global_fn

Macro set_exported_global_fn 

set_exported_global_fn!() { /* proc-macro */ }
๐Ÿ‘ŽDeprecated since 1.18.0
Macro to register a plugin function into a Rhai Module and expose it globally.

Deprecated

This macro is deprecated as it performs no additional value.

This method will be removed in the next major version.